@@ -90,12 +90,15 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
-		if response["succcess"] in [True, "True", "true"]:
+		if response["success"] in [True, "True", "true"]:
+			message = response["message"]
 			try:  del response["message"]
 			except: a=1
 			try:  del response["error"]
 			except: a=1
-			return r3sponse.success_response(response["message"], response)
+			try:  del response["success"]
+			except: a=1
+			return r3sponse.success_response(message, response)
 		else:
 			return r3sponse.error_response(response["error"])
 	def get(self, group=None, id=None):
@@ -112,12 +115,15 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
-		if response["succcess"] in [True, "True", "true"]:
+		if response["success"] in [True, "True", "true"]:
+			message = response["message"]
 			try:  del response["message"]
 			except: a=1
+			try:  del response["success"]
+			except: a=1
 			try:  del response["error"]
 			except: a=1
-			return r3sponse.success_response(response["message"], response)
+			return r3sponse.success_response(message, response)
 		else:
 			return r3sponse.error_response(response["error"])
 	def app(self):
@@ -141,19 +147,20 @@ class WebServer(objects.Thread):
 					value = self.cache[group][id]
 			except KeyError:
 				return r3sponse.error_response(f"There is no data cached for {tag}.").json()
+			print("VALUE:",value)
 			return r3sponse.success_response(f"Successfully retrieved {tag}.", {
 				"group":group,
 				"data":value,
 			}).json()
 		@app.route('/set')
-		def set__():
+		def set():
 			#token = flask.request.args.get('token')
 			#if token != self.token():
 			#	return r3sponse.error_response(f"Provided an invalid token {token}.").json()
 			group = flask.request.args.get('group')
 			id = flask.request.args.get('id')
 			if id in ["none", "null", "None"]: id = None
-			value = flask.request.args.get('value')
+			value = flask.request.args.get('data')
 			if id == None:
 				tag = f"{group}"
 				self.cache[group] = value
@@ -164,7 +171,7 @@ class WebServer(objects.Thread):
 				self.cache[group][id] = value
 			return r3sponse.success_response(f"Successfully cached {tag}.").json()
 		@app.route('/active')
-		def active__():
+		def active():
 			#token = flask.request.args.get('token')
 			#if token != self.token():
 			#	return r3sponse.error_response(f"Provided an invalid token {token}.").json()
